"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.downloadJatsFromUrl = void 0;
const doi_utils_1 = __importDefault(require("doi-utils"));
const node_fetch_1 = __importDefault(require("node-fetch"));
const myst_cli_utils_1 = require("myst-cli-utils");
const resolvers_1 = require("./resolvers");
function dowloadFromUrl(session, jatsUrl) {
    return __awaiter(this, void 0, void 0, function* () {
        session.log.debug(`Fetching JATS from ${jatsUrl}`);
        const jatsResp = yield (0, node_fetch_1.default)(jatsUrl);
        if (!jatsResp.ok)
            throw new Error(`Problem fetching JATS from ${jatsUrl}`);
        const contentType = jatsResp.headers.get('content-type');
        if (!(contentType === 'application/xml' || (contentType === null || contentType === void 0 ? void 0 : contentType.includes('text/plain')))) {
            throw new Error(`Expected content-type "application/xml" instead we got ${contentType} for ${jatsUrl}`);
        }
        const data = yield jatsResp.text();
        return data;
    });
}
function downloadJatsFromUrl(session, urlOrDoi, resolvers) {
    return __awaiter(this, void 0, void 0, function* () {
        if (doi_utils_1.default.validate(urlOrDoi)) {
            const jatsUrl = yield (0, resolvers_1.resolveJatsUrlFromDoi)(session, urlOrDoi, resolvers);
            const data = yield dowloadFromUrl(session, jatsUrl);
            return data;
        }
        if ((0, myst_cli_utils_1.isUrl)(urlOrDoi)) {
            const data = yield dowloadFromUrl(session, urlOrDoi);
            return data;
        }
        throw new Error(`Could not find ${urlOrDoi} locally, and it doesn't look like a URL or DOI`);
    });
}
exports.downloadJatsFromUrl = downloadJatsFromUrl;
